@@ -20,6 +20,7 @@
 
 #include "datawidget.h"
 #include "entryglom.h"
+#include "labelglom.h"
 #include "comboentryglom.h"
 #include "comboglom.h"
 #include "textviewglom.h"
@@ -234,14 +235,19 @@ void DataWidget::set_value(const Gnome::Gda::Value& value)
   Gtk::Widget* widget = get_data_child_widget();
   LayoutWidgetField* generic_field_widget = dynamic_cast<LayoutWidgetField*>(widget);
   if(generic_field_widget)
+  {
+    //if(generic_field_widget->get_layout_item())
+    //  std::cout << "DataWidget::set_value(): generic_field_widget->get_layout_item()->get_name()=" << generic_field_widget->get_layout_item()->get_name() << std::endl;
+
     generic_field_widget->set_value(value);
+  }
   else
   {
     Gtk::CheckButton* checkbutton = dynamic_cast<Gtk::CheckButton*>(widget);
     if(checkbutton)
     {
       bool bValue = false;
-      if(!value.is_null())
+      if(!value.is_null() && value.get_value_type() == Gnome::Gda::VALUE_TYPE_BOOLEAN)
         bValue = value.get_bool();
 
       checkbutton->set_active( bValue );
@@ -364,6 +370,19 @@ void DataWidget::set_editable(bool editable)
     Gtk::CheckButton* checkbutton = dynamic_cast<Gtk::CheckButton*>(child);
     if(checkbutton)
       checkbutton->set_sensitive(editable);
+    else
+    {
+      Gtk::ComboBoxEntry* comboboxentry = dynamic_cast<Gtk::ComboBoxEntry*>(child);
+      if(comboboxentry)
+      {
+        Gtk::Entry* entry = comboboxentry->get_entry();
+        if(entry)
+          entry->set_editable(editable);
+
+        //But the menu still causes the entry to change, so we must disable it completely:
+        comboboxentry->set_sensitive(editable);
+      }
+    }
   }
 }
 
@@ -583,7 +602,9 @@ void DataWidget::on_menupopup_activate_layout_properties()
     sharedptr<LayoutItem_Field> itemchosen = offer_field_layout(layoutField);
     if(itemchosen)
     {
-      set_layout_item(itemchosen, m_table_name);
+      *layoutField = *itemchosen;
+      //set_layout_item(itemchosen, m_table_name);
+
       signal_layout_changed().emit();
     }
   }
